@@ -8,4 +8,8 @@ __maintainer__ = "Padraic Shafer"
 __email__ = "PShafer@lbl.gov"
 __status__ = "Development"
 
+import logging
+
+logger = logging.getLogger(__name__)
+
 from .version import __version__, __date__, __credits__
